@@ -421,7 +421,7 @@ plotDAG <- function(DAG, tmax = NULL, xjitter, yjitter, node.action.color, verte
     igraph::V(g)[igraph::V(g)$name%in%latent.v]$shape <- "circle"
     # igraph::E(g)[from(igraph::V(g)[igraph::V(g)$name%in%latent.v])]$lty <- 2 # dashed
     # to prevent a NOTE from using undeclared global "from" in igraph indexing
-    Eg.sel <- eval(parse(text="igraph::E(g)[from(igraph::V(g)[igraph::V(g)$name%in%latent.v])]$lty <- 5")) # long dash
+    Eg.sel <- eval(parse(text="igraph::E(g)[.from(igraph::V(g)[igraph::V(g)$name%in%latent.v])]$lty <- 5")) # long dash
   }
   # use user-supplied custom labels for DAG nodes:
   if (!missing(customvlabs)) {
